﻿using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
using MySQL.GUI.Workbench;

// General Information about an assembly is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("MySQL Workbench")]
[assembly: AssemblyDescription("MySQL Database Design Tool")]
#if EDITION_SE
[assembly: AssemblyConfiguration("SE")]
#elif EDITION_OSS
[assembly: AssemblyConfiguration("CE")]
#else
[assembly: AssemblyConfiguration("UNKNOWN EDITION")]
#endif
[assembly: AssemblyCompany("Oracle Corporation")]
[assembly: AssemblyProduct("MySQL Workbench")]
[assembly: AssemblyCopyright("2006-2011")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Setting ComVisible to false makes the types in this assembly not visible 
// to COM components.  If you need to access a type in this assembly from 
// COM, set the ComVisible attribute to true on that type.
[assembly: ComVisible(false)]

// The following GUID is for the ID of the typelib if this project is exposed to COM
[assembly: Guid("ff29df99-51b2-4792-8bdf-69e5ee8df428")]

// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
[assembly: AssemblyVersion("5.2.35.7915")]
[assembly: AssemblyFileVersion("5.2.35.7915")]
[assembly: AssemblyReleaseType("")]
